==> kubernetes-model-batch-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/batch/v1beta1/CronJobSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.batch.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class CronJobSpecFluentImpl<A extends io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent<A>{
  public CronJobSpecFluentImpl() {
  }
  public CronJobSpecFluentImpl(io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpec instance) {
    this.withConcurrencyPolicy(instance.getConcurrencyPolicy()); 
    this.withFailedJobsHistoryLimit(instance.getFailedJobsHistoryLimit()); 
    this.withJobTemplate(instance.getJobTemplate()); 
    this.withSchedule(instance.getSchedule()); 
    this.withStartingDeadlineSeconds(instance.getStartingDeadlineSeconds()); 
    this.withSuccessfulJobsHistoryLimit(instance.getSuccessfulJobsHistoryLimit()); 
    this.withSuspend(instance.getSuspend()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String concurrencyPolicy;
  private java.lang.Integer failedJobsHistoryLimit;
  private io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpecBuilder jobTemplate;
  private java.lang.String schedule;
  private java.lang.Long startingDeadlineSeconds;
  private java.lang.Integer successfulJobsHistoryLimit;
  private java.lang.Boolean suspend;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getConcurrencyPolicy() {
    return this.concurrencyPolicy;
  }
  public A withConcurrencyPolicy(java.lang.String concurrencyPolicy) {
    this.concurrencyPolicy=concurrencyPolicy; return (A) this;
  }
  public java.lang.Boolean hasConcurrencyPolicy() {
    return this.concurrencyPolicy != null;
  }
  
  /**
   * Method is deprecated. use withConcurrencyPolicy instead.
   */
  @java.lang.Deprecated
  public A withNewConcurrencyPolicy(java.lang.String arg0) {
    return (A)withConcurrencyPolicy(new String(arg0));
  }
  public java.lang.Integer getFailedJobsHistoryLimit() {
    return this.failedJobsHistoryLimit;
  }
  public A withFailedJobsHistoryLimit(java.lang.Integer failedJobsHistoryLimit) {
    this.failedJobsHistoryLimit=failedJobsHistoryLimit; return (A) this;
  }
  public java.lang.Boolean hasFailedJobsHistoryLimit() {
    return this.failedJobsHistoryLimit != null;
  }
  
  /**
   * This method has been deprecated, please use method buildJobTemplate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpec getJobTemplate() {
    return this.jobTemplate!=null?this.jobTemplate.build():null;
  }
  public io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpec buildJobTemplate() {
    return this.jobTemplate!=null?this.jobTemplate.build():null;
  }
  public A withJobTemplate(io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpec jobTemplate) {
    _visitables.get("jobTemplate").remove(this.jobTemplate);
    if (jobTemplate!=null){ this.jobTemplate= new io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpecBuilder(jobTemplate); _visitables.get("jobTemplate").add(this.jobTemplate);} return (A) this;
  }
  public java.lang.Boolean hasJobTemplate() {
    return this.jobTemplate != null;
  }
  public io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent.JobTemplateNested<A> withNewJobTemplate() {
    return new io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluentImpl.JobTemplateNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent.JobTemplateNested<A> withNewJobTemplateLike(io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpec item) {
    return new io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluentImpl.JobTemplateNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent.JobTemplateNested<A> editJobTemplate() {
    return withNewJobTemplateLike(getJobTemplate());
  }
  public io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent.JobTemplateNested<A> editOrNewJobTemplate() {
    return withNewJobTemplateLike(getJobTemplate() != null ? getJobTemplate(): new io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpecBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent.JobTemplateNested<A> editOrNewJobTemplateLike(io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpec item) {
    return withNewJobTemplateLike(getJobTemplate() != null ? getJobTemplate(): item);
  }
  public java.lang.String getSchedule() {
    return this.schedule;
  }
  public A withSchedule(java.lang.String schedule) {
    this.schedule=schedule; return (A) this;
  }
  public java.lang.Boolean hasSchedule() {
    return this.schedule != null;
  }
  
  /**
   * Method is deprecated. use withSchedule instead.
   */
  @java.lang.Deprecated
  public A withNewSchedule(java.lang.String arg0) {
    return (A)withSchedule(new String(arg0));
  }
  public java.lang.Long getStartingDeadlineSeconds() {
    return this.startingDeadlineSeconds;
  }
  public A withStartingDeadlineSeconds(java.lang.Long startingDeadlineSeconds) {
    this.startingDeadlineSeconds=startingDeadlineSeconds; return (A) this;
  }
  public java.lang.Boolean hasStartingDeadlineSeconds() {
    return this.startingDeadlineSeconds != null;
  }
  public java.lang.Integer getSuccessfulJobsHistoryLimit() {
    return this.successfulJobsHistoryLimit;
  }
  public A withSuccessfulJobsHistoryLimit(java.lang.Integer successfulJobsHistoryLimit) {
    this.successfulJobsHistoryLimit=successfulJobsHistoryLimit; return (A) this;
  }
  public java.lang.Boolean hasSuccessfulJobsHistoryLimit() {
    return this.successfulJobsHistoryLimit != null;
  }
  public java.lang.Boolean getSuspend() {
    return this.suspend;
  }
  public A withSuspend(java.lang.Boolean suspend) {
    this.suspend=suspend; return (A) this;
  }
  public java.lang.Boolean hasSuspend() {
    return this.suspend != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CronJobSpecFluentImpl that = (CronJobSpecFluentImpl) o;
    if (concurrencyPolicy != null ? !concurrencyPolicy.equals(that.concurrencyPolicy) :that.concurrencyPolicy != null) return false;
    if (failedJobsHistoryLimit != null ? !failedJobsHistoryLimit.equals(that.failedJobsHistoryLimit) :that.failedJobsHistoryLimit != null) return false;
    if (jobTemplate != null ? !jobTemplate.equals(that.jobTemplate) :that.jobTemplate != null) return false;
    if (schedule != null ? !schedule.equals(that.schedule) :that.schedule != null) return false;
    if (startingDeadlineSeconds != null ? !startingDeadlineSeconds.equals(that.startingDeadlineSeconds) :that.startingDeadlineSeconds != null) return false;
    if (successfulJobsHistoryLimit != null ? !successfulJobsHistoryLimit.equals(that.successfulJobsHistoryLimit) :that.successfulJobsHistoryLimit != null) return false;
    if (suspend != null ? !suspend.equals(that.suspend) :that.suspend != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(concurrencyPolicy,  failedJobsHistoryLimit,  jobTemplate,  schedule,  startingDeadlineSeconds,  successfulJobsHistoryLimit,  suspend,  additionalProperties,  super.hashCode());
  }
  public class JobTemplateNestedImpl<N> extends io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpecFluentImpl<io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent.JobTemplateNested<N>> implements io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent.JobTemplateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    JobTemplateNestedImpl(io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpec item) {
      this.builder = new io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpecBuilder(this, item);
    }
    JobTemplateNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpecBuilder(this);
    }
    io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpecBuilder builder;
    public N and() {
      return (N) CronJobSpecFluentImpl.this.withJobTemplate(builder.build());
    }
    public N endJobTemplate() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-batch-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/batch/v1beta1/CronJobSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.batch.v1beta1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class CronJobSpecFluentImpl<A extends io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent<A>{
  public CronJobSpecFluentImpl() {
  }
  public CronJobSpecFluentImpl(io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpec instance) {
    this.withConcurrencyPolicy(instance.getConcurrencyPolicy()); 
    this.withFailedJobsHistoryLimit(instance.getFailedJobsHistoryLimit()); 
    this.withJobTemplate(instance.getJobTemplate()); 
    this.withSchedule(instance.getSchedule()); 
    this.withStartingDeadlineSeconds(instance.getStartingDeadlineSeconds()); 
    this.withSuccessfulJobsHistoryLimit(instance.getSuccessfulJobsHistoryLimit()); 
    this.withSuspend(instance.getSuspend()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String concurrencyPolicy;
  private java.lang.Integer failedJobsHistoryLimit;
  private io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpecBuilder jobTemplate;
  private java.lang.String schedule;
  private java.lang.Long startingDeadlineSeconds;
  private java.lang.Integer successfulJobsHistoryLimit;
  private java.lang.Boolean suspend;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getConcurrencyPolicy() {
    return this.concurrencyPolicy;
  }
  public A withConcurrencyPolicy(java.lang.String concurrencyPolicy) {
    this.concurrencyPolicy=concurrencyPolicy; return (A) this;
  }
  public java.lang.Boolean hasConcurrencyPolicy() {
    return this.concurrencyPolicy != null;
  }
  
  /**
   * Method is deprecated. use withConcurrencyPolicy instead.
   */
  @java.lang.Deprecated
  public A withNewConcurrencyPolicy(java.lang.String arg0) {
    return (A)withConcurrencyPolicy(new String(arg0));
  }
  public java.lang.Integer getFailedJobsHistoryLimit() {
    return this.failedJobsHistoryLimit;
  }
  public A withFailedJobsHistoryLimit(java.lang.Integer failedJobsHistoryLimit) {
    this.failedJobsHistoryLimit=failedJobsHistoryLimit; return (A) this;
  }
  public java.lang.Boolean hasFailedJobsHistoryLimit() {
    return this.failedJobsHistoryLimit != null;
  }
  
  /**
   * This method has been deprecated, please use method buildJobTemplate instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpec getJobTemplate() {
    return this.jobTemplate!=null?this.jobTemplate.build():null;
  }
  public io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpec buildJobTemplate() {
    return this.jobTemplate!=null?this.jobTemplate.build():null;
  }
  public A withJobTemplate(io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpec jobTemplate) {
    _visitables.get("jobTemplate").remove(this.jobTemplate);
    if (jobTemplate!=null){ this.jobTemplate= new io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpecBuilder(jobTemplate); _visitables.get("jobTemplate").add(this.jobTemplate);} return (A) this;
  }
  public java.lang.Boolean hasJobTemplate() {
    return this.jobTemplate != null;
  }
  public io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent.JobTemplateNested<A> withNewJobTemplate() {
    return new io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluentImpl.JobTemplateNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent.JobTemplateNested<A> withNewJobTemplateLike(io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpec item) {
    return new io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluentImpl.JobTemplateNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent.JobTemplateNested<A> editJobTemplate() {
    return withNewJobTemplateLike(getJobTemplate());
  }
  public io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent.JobTemplateNested<A> editOrNewJobTemplate() {
    return withNewJobTemplateLike(getJobTemplate() != null ? getJobTemplate(): new io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpecBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent.JobTemplateNested<A> editOrNewJobTemplateLike(io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpec item) {
    return withNewJobTemplateLike(getJobTemplate() != null ? getJobTemplate(): item);
  }
  public java.lang.String getSchedule() {
    return this.schedule;
  }
  public A withSchedule(java.lang.String schedule) {
    this.schedule=schedule; return (A) this;
  }
  public java.lang.Boolean hasSchedule() {
    return this.schedule != null;
  }
  
  /**
   * Method is deprecated. use withSchedule instead.
   */
  @java.lang.Deprecated
  public A withNewSchedule(java.lang.String arg0) {
    return (A)withSchedule(new String(arg0));
  }
  public java.lang.Long getStartingDeadlineSeconds() {
    return this.startingDeadlineSeconds;
  }
  public A withStartingDeadlineSeconds(java.lang.Long startingDeadlineSeconds) {
    this.startingDeadlineSeconds=startingDeadlineSeconds; return (A) this;
  }
  public java.lang.Boolean hasStartingDeadlineSeconds() {
    return this.startingDeadlineSeconds != null;
  }
  public java.lang.Integer getSuccessfulJobsHistoryLimit() {
    return this.successfulJobsHistoryLimit;
  }
  public A withSuccessfulJobsHistoryLimit(java.lang.Integer successfulJobsHistoryLimit) {
    this.successfulJobsHistoryLimit=successfulJobsHistoryLimit; return (A) this;
  }
  public java.lang.Boolean hasSuccessfulJobsHistoryLimit() {
    return this.successfulJobsHistoryLimit != null;
  }
  public java.lang.Boolean getSuspend() {
    return this.suspend;
  }
  public A withSuspend(java.lang.Boolean suspend) {
    this.suspend=suspend; return (A) this;
  }
  public java.lang.Boolean hasSuspend() {
    return this.suspend != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CronJobSpecFluentImpl that = (CronJobSpecFluentImpl) o;
    if (concurrencyPolicy != null ? !concurrencyPolicy.equals(that.concurrencyPolicy) :that.concurrencyPolicy != null) return false;
    if (failedJobsHistoryLimit != null ? !failedJobsHistoryLimit.equals(that.failedJobsHistoryLimit) :that.failedJobsHistoryLimit != null) return false;
    if (jobTemplate != null ? !jobTemplate.equals(that.jobTemplate) :that.jobTemplate != null) return false;
    if (schedule != null ? !schedule.equals(that.schedule) :that.schedule != null) return false;
    if (startingDeadlineSeconds != null ? !startingDeadlineSeconds.equals(that.startingDeadlineSeconds) :that.startingDeadlineSeconds != null) return false;
    if (successfulJobsHistoryLimit != null ? !successfulJobsHistoryLimit.equals(that.successfulJobsHistoryLimit) :that.successfulJobsHistoryLimit != null) return false;
    if (suspend != null ? !suspend.equals(that.suspend) :that.suspend != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(concurrencyPolicy,  failedJobsHistoryLimit,  jobTemplate,  schedule,  startingDeadlineSeconds,  successfulJobsHistoryLimit,  suspend,  additionalProperties,  super.hashCode());
  }
  public class JobTemplateNestedImpl<N> extends io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpecFluentImpl<io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent.JobTemplateNested<N>> implements io.fabric8.kubernetes.api.model.batch.v1beta1.CronJobSpecFluent.JobTemplateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    JobTemplateNestedImpl(io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpec item) {
      this.builder = new io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpecBuilder(this, item);
    }
    JobTemplateNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpecBuilder(this);
    }
    io.fabric8.kubernetes.api.model.batch.v1beta1.JobTemplateSpecBuilder builder;
    public N and() {
      return (N) CronJobSpecFluentImpl.this.withJobTemplate(builder.build());
    }
    public N endJobTemplate() {
      return and();
    }
    
  }
  
}
